[Erp5-report] r40378 kazuhiko - in /erp5/trunk/products/ERP5Security: ./ tests/

nobody at svn.erp5.org nobody at svn.erp5.org
Thu Nov 18 15:42:12 CET 2010


Author: kazuhiko
Date: Thu Nov 18 15:42:11 2010
New Revision: 40378

URL: http://svn.erp5.org?rev=40378&view=rev
Log:
rename ERP5ExternalAuthPlugin -> ERP5ExternalAuthenticationPlugin.

Modified:
    erp5/trunk/products/ERP5Security/ERP5ExternalAuthenticationPlugin.py
    erp5/trunk/products/ERP5Security/tests/testERP5Security.py

Modified: erp5/trunk/products/ERP5Security/ERP5ExternalAuthenticationPlugin.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5Security/ERP5ExternalAuthenticationPlugin.py?rev=40378&r1=40377&r2=40378&view=diff
==============================================================================
--- erp5/trunk/products/ERP5Security/ERP5ExternalAuthenticationPlugin.py [utf8] (original)
+++ erp5/trunk/products/ERP5Security/ERP5ExternalAuthenticationPlugin.py [utf8] Thu Nov 18 15:42:11 2010
@@ -72,7 +72,7 @@ class ERP5ExternalAuthicationPlugin(ERP5
   request header, like REMOTE_USER, openAMid, etc.
   """
 
-  meta_type = "ERP5 External Auth Plugin"
+  meta_type = "ERP5 External Authentication Plugin"
   security = ClassSecurityInfo()
   user_id_key = ''
 

Modified: erp5/trunk/products/ERP5Security/tests/testERP5Security.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5Security/tests/testERP5Security.py?rev=40378&r1=40377&r2=40378&view=diff
==============================================================================
--- erp5/trunk/products/ERP5Security/tests/testERP5Security.py [utf8] (original)
+++ erp5/trunk/products/ERP5Security/tests/testERP5Security.py [utf8] Thu Nov 18 15:42:11 2010
@@ -725,19 +725,19 @@ class TestLocalRoleManagement(ERP5TypeTe
 
   def testERP5ExternalAuthicationPlugin(self):
     """
      Make sure that we can grant security using a ERP5 External Auth Plugin.
     """
     user_id_key = 'openAMid'
     # add key authentication PAS plugin
     portal = self.portal
     uf = portal.acl_users
     uf.manage_addProduct['ERP5Security'].addERP5ExternalAuthicationPlugin(
-      id='erp5_external_auth_plugin', \
-      title='ERP5 External Auth Plugin',\
+      id='erp5_external_authentication_plugin', \
+      title='ERP5 External Authentication Plugin',\
       user_id_key=user_id_key,)
 
-    erp5_external_auth_plugin = getattr(uf, 'erp5_external_auth_plugin')
-    erp5_external_auth_plugin.manage_activateInterfaces(
+    erp5_external_authentication_plugin = getattr(uf, 'erp5_external_authentication_plugin')
+    erp5_external_authentication_plugin.manage_activateInterfaces(
       interfaces=['IExtractionPlugin',
                   'IAuthenticationPlugin'])
     self.stepTic()
@@ -725,19 +725,19 @@ class TestLocalRoleManagement(ERP5TypeTe
   def testERP5ExternalAuthicationPlugin(self):
     """
-     Make sure that we can grant security using a ERP5 External Auth Plugin.
+     Make sure that we can grant security using a ERP5 External Authentication Plugin.
     """
     user_id_key = 'openAMid'




More information about the Erp5-report mailing list